"use strict";

require("core-js/modules/es.array.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractCategoryScores = void 0;

var _get2 = _interopRequireDefault(require("lodash/get"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Extract lighthouse category scores
 *
 * @param {import("../../../types").LighthouseSource} lighthouseSource
 *
 * @typedef {Object} CategoryScoresMetrics
 * @property {import("../../../types").LighthouseMetricsCategoryScores} metrics
 *
 * @return CategoryScoresMetrics
 */
const METRIC_KEYS = {
  performanceScore: 'performance',
  accessibilityScore: 'accessibility',
  bestPracticesScore: 'best-practices',
  seoScore: 'seo',
  pwaScore: 'pwa'
};

const extractCategoryScores = lighthouseSource => {
  const metrics = Object.entries(METRIC_KEYS).reduce((agg, [metricKey, lighthouseCategoryId]) => _objectSpread({}, agg, {
    [metricKey]: {
      value: (0, _get2.default)(lighthouseSource, ['categories', lighthouseCategoryId, 'score'], 0) * 100
    }
  }), {});
  return {
    metrics
  };
};

exports.extractCategoryScores = extractCategoryScores;