"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractScoreCategoryScores = void 0;

var _round2 = _interopRequireDefault(require("lodash/round"));

var _mean2 = _interopRequireDefault(require("lodash/mean"));

var _get2 = _interopRequireDefault(require("lodash/get"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Extract average score
 *
 * @param {import("../../../types").LighthouseSource} lighthouseSource
 * @param {Object} currentExtractedData
 *
 * @typedef {Object} CategoryScoresMetrics
 * @property {import("../../../types").LighthouseMetricsScore} metrics
 *
 * @return CategoryScoresMetrics
 */
const SCORES = ['performanceScore', 'accessibilityScore', 'bestPracticesScore', 'seoScore', 'pwaScore'];

const extractScoreCategoryScores = (lighthouseSource, currentExtractedData = {}) => {
  const scores = SCORES.map(scoreKey => (0, _get2.default)(currentExtractedData, ['metrics', scoreKey, 'value']));
  const score = {
    value: (0, _round2.default)((0, _mean2.default)(scores), 2)
  };
  return {
    metrics: {
      score
    }
  };
};

exports.extractScoreCategoryScores = extractScoreCategoryScores;