"use strict";

require("core-js/modules/es.array.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractAudits = void 0;

var _get2 = _interopRequireDefault(require("lodash/get"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Extract lighthouse audits values
 *
 * @param {import("../../../types").LighthouseSource} lighthouseSource
 *
 * @typedef {Object} CategoryAuditMetrics
 * @property {import("../../../types").LighthouseMetricsAudits} metrics
 *
 * @return CategoryAuditMetrics
 */
const METRIC_KEYS = {
  speedIndex: 'speed-index',
  firstMeaningfulPaint: 'first-meaningful-paint',
  timeToFirstByte: 'time-to-first-byte',
  firstInteractive: 'first-cpu-idle',
  totalByteWeight: 'total-byte-weight',
  domSize: 'dom-size'
};

const extractAudits = lighthouseSource => {
  const metrics = Object.entries(METRIC_KEYS).reduce((agg, [metricKey, lighthouseAuditId]) => _objectSpread({}, agg, {
    [metricKey]: {
      value: (0, _get2.default)(lighthouseSource, ['audits', lighthouseAuditId, 'numericValue'], 0)
    }
  }), {});
  return {
    metrics
  };
};

exports.extractAudits = extractAudits;